"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.format = undefined;

var _semver = require("semver");

var _chast = require("chast");

var _unistUtilVisitChildren = require("unist-util-visit-children");

var _unistUtilVisitChildren2 = _interopRequireDefault(_unistUtilVisitChildren);

var _unistUtilInspect = require("unist-util-inspect");

var _unistUtilInspect2 = _interopRequireDefault(_unistUtilInspect);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var format = exports.format = function format(ast) {
  var categories = {};

  var visitCategories = (0, _unistUtilVisitChildren2.default)(function (category) {
    if (!categories[category.text]) {
      categories[category.text] = [];
    }
    var changes = category.children.map(function (_ref) {
      var text = _ref.text;
      return text;
    });

    categories[category.text] = [].concat(_toConsumableArray(categories[category.text]), _toConsumableArray(changes));
  });

  var visitVersions = (0, _unistUtilVisitChildren2.default)(visitCategories);

  visitVersions(ast);

  return Object.keys(categories).filter(function (category) {
    return categories[category].length > 0;
  }).map(function (category) {
    return "### " + category + "\n\n" + categories[category].map(function (change) {
      return "* " + change;
    }).join("\n");
  }).join("\n\n");
};

exports.default = function (changeLog) {
  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$since = _ref2.since,
      since = _ref2$since === undefined ? "0.0.0" : _ref2$since,
      _ref2$inclusive = _ref2.inclusive,
      inclusive = _ref2$inclusive === undefined ? false : _ref2$inclusive;

  var ast = (0, _chast.parse)(changeLog);
  var comparison = inclusive ? _semver.gte : _semver.gt;

  ast.children = ast.children.filter(function (node) {

    var nodeSemver = (0, _semver.coerce)(node.semver);
    if (nodeSemver == null) {
      nodeSemver = "0.0.0";
    }

    return comparison(nodeSemver, since);
  });
  return ast;
};